Changelog
=========

0.0.5 (2019-01-22)
~~~~~~~~~~~~~~~~~~

* Fix packaging

* Add EventSession.access_token and EventSession.token_expiry attributes


0.0.4 (2019-01-21)
~~~~~~~~~~~~~~~~~~

* Cleanup of logging


0.0.3 (2019-01-10)
~~~~~~~~~~~~~~~~~~

* Add session renewal on access token expiry

* Improve exception on failure to log in


0.0.2 (2018-12-20)
~~~~~~~~~~~~~~~~~~

* Initial version
